@@ -19,38 +19,40 @@ package org.gradle.api.internal.initialization.loadercache;
 import com.google.common.collect.Iterators;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
-import org.gradle.api.internal.changedetection.state.FileSnapshotter;
+import com.google.common.hash.HashCode;
+import com.google.common.hash.Hashing;
+import org.gradle.api.internal.hash.Hasher;
+import org.gradle.internal.FileUtils;
+import org.gradle.internal.classloader.ClassPathSnapshot;
+import org.gradle.internal.classloader.ClassPathSnapshotter;
 import org.gradle.internal.classpath.ClassPath;
-import org.gradle.util.GFileUtils;
 
 import java.io.File;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
-import java.util.zip.Adler32;
 
 public class HashClassPathSnapshotter implements ClassPathSnapshotter {
 
-    private final FileSnapshotter fileSnapshotter;
+    private final Hasher hasher;
 
-    public HashClassPathSnapshotter(FileSnapshotter fileSnapshotter) {
-        this.fileSnapshotter = fileSnapshotter;
+    public HashClassPathSnapshotter(Hasher hasher) {
+        this.hasher = hasher;
     }
 
+    @Override
     public ClassPathSnapshot snapshot(ClassPath classPath) {
-        List<String> visitedFilePaths = Lists.newLinkedList();
-        Set<File> visitedDirs = Sets.newLinkedHashSet();
-        List<File> cpFiles = classPath.getAsFiles();
-
-        Adler32 checksum = new Adler32();
+        final List<String> visitedFilePaths = Lists.newLinkedList();
+        final Set<File> visitedDirs = Sets.newLinkedHashSet();
+        final List<File> cpFiles = classPath.getAsFiles();
+        com.google.common.hash.Hasher checksum = Hashing.md5().newHasher();
         hash(checksum, visitedFilePaths, visitedDirs, cpFiles.iterator());
-        return new ClassPathSnapshotImpl(visitedFilePaths, checksum.getValue());
+        return new HashClassPathSnapshot(visitedFilePaths, checksum.hash());
     }
 
-    private void hash(Adler32 combinedHash, List<String> visitedFilePaths, Set<File> visitedDirs, Iterator<File> toHash) {
+    private void hash(com.google.common.hash.Hasher combinedHash, List<String> visitedFilePaths, Set<File> visitedDirs, Iterator<File> toHash) {
         while (toHash.hasNext()) {
-            File file = toHash.next();
-            file = GFileUtils.canonicalise(file);
+            File file = FileUtils.canonicalize(toHash.next());
             if (file.isDirectory()) {
                 if (visitedDirs.add(file)) {
                     //in theory, awkward symbolic links can lead to recursion problems.
@@ -59,23 +61,27 @@ public class HashClassPathSnapshotter implements ClassPathSnapshotter {
                 }
             } else if (file.isFile()) {
                 visitedFilePaths.add(file.getAbsolutePath());
-                combinedHash.update(fileSnapshotter.snapshot(file).getHash());
+                combinedHash.putBytes(hasher.hash(file).asBytes());
             }
             //else an empty folder - a legit situation
         }
     }
 
-    private static class ClassPathSnapshotImpl implements ClassPathSnapshot {
+    private static class HashClassPathSnapshot implements ClassPathSnapshot {
         private final List<String> files;
-        private final long hash;
+        private final HashCode hash;
 
-        public ClassPathSnapshotImpl(List<String> files, long hash) {
+        public HashClassPathSnapshot(List<String> files, HashCode hash) {
             assert files != null;
-
             this.files = files;
             this.hash = hash;
         }
 
+        @Override
+        public HashCode getStrongHash() {
+            return hash;
+        }
+
         @Override
         public boolean equals(Object o) {
             if (this == o) {
@@ -85,16 +91,16 @@ public class HashClassPathSnapshotter implements ClassPathSnapshotter {
                 return false;
             }
 
-            ClassPathSnapshotImpl that = (ClassPathSnapshotImpl) o;
+            HashClassPathSnapshot that = (HashClassPathSnapshot) o;
 
-            return hash == that.hash && files.equals(that.files);
+            return hash.equals(that.hash) && files.equals(that.files);
         }
 
         @Override
         public int hashCode() {
             int result = files.hashCode();
-            result = 31 * result + (int) (hash ^ (hash >>> 32));
+            result = 31 * result + hash.hashCode();
             return result;
         }
     }
-}
\ No newline at end of file
+}
